@@ -48,6 +48,7 @@ OC.L10N.register(
     "Subject" : "Asunto",
     "Upload attachment" : "Cargar adjunto",
     "Add attachment from Files" : "Agregar adjunto desd Archivos",
+    "Smart picker" : "Selector inteligente",
     "Enter a date" : "Ingrese una fecha",
     "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
     "Choose" : "Seleccionar",
@@ -75,24 +76,30 @@ OC.L10N.register(
     "Choose a folder to store the attachment in" : "Seleccciona la carpeta en la cual almacenar el adjunto",
     "Save all to Files" : "Guardar todo a Archivos",
     "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad. ",
+    "Quoted text" : "Texto citado",
     "Move" : "Mover",
     "Quota" : "Cuota",
     "Saving" : "Guardando",
+    "Move up" : "Mover arriba",
+    "Move down" : "Mover abajo",
     "Remove account" : "Eliminar cuenta",
+    "Loading …" : "Cargando …",
     "Mark all as read" : "Marcar todos como leídos",
     "Edit name" : "Editar nombre",
     "Clear cache" : "Borrar el caché",
     "New message" : "Mensaje nuevo",
     "Retry" : "Reintentar",
     "Sending …" : "Enviando ...",
+    "First day" : "Primer día",
     "Message" : "Mensaje",
     "Copy to clipboard" : "Copiar al portapapeles",
     "Add" : "Agregar",
     "Close" : "Cerrar",
+    "Date" : "Fecha",
     "Tags" : "Etiquetas",
     "Select tags" : "Selecciona las etiquetas",
     "Clear" : "Limpiar",
-    "Date" : "Fecha",
+    "Last 7 days" : "Últimos 7 días",
     "Disabled" : "Deshabilitado",
     "Enabled" : "Habilitado",
     "Custom" : "Personalizado",
@@ -100,6 +107,7 @@ OC.L10N.register(
     "Tag already exists" : "La etiqueta ya existe",
     "Not found" : "No encontrado",
     "Remove" : "Eliminar",
+    "Untitled event" : "Evento sin título",
     "Reset" : "Reiniciar",
     "Client ID" : "ID del cliente",
     "Client secret" : "Secreto del cliente",
