@@ -19,7 +19,7 @@ OC.L10N.register(
     "Your session has expired. The page will be reloaded." : "Ваш сеанс закінчився. Сторінка буде перезавантажена.",
     "Drafts are saved in:" : "Чернетки зберігаються в:",
     "Sent messages are saved in:" : "Надіслані повідомлення зберігаються в:",
-    "Deleted messages are moved in:" : "Видалені повідомлення переміщуються в:",
+    "Deleted messages are moved in:" : "Вилучені листи буде переміщено до:",
     "Archived messages are moved in:" : "Архівні повідомлення перенесено:",
     "Snoozed messages are moved in:" : "Відкладені повідомлення буде переміщено до:",
     "Junk messages are saved in:" : "Спам зберігатиметься у:",
@@ -99,6 +99,10 @@ OC.L10N.register(
     "Create alias" : "Створити синонім",
     "Cancel" : "Скасувати",
     "Mail settings" : "Налаштування пошти",
+    "Layout" : "Подання",
+    "List" : "Список",
+    "Vertical split" : "Розділено по вертикалі",
+    "Horizontal split" : "Розділено по горизонталі",
     "Account creation" : "Створення облікового запису",
     "Add mail account" : "Додати обліковий запис",
     "Activate body search" : "Увімкнути пошук у тілі листа",
@@ -134,6 +138,7 @@ OC.L10N.register(
     "Automatically classify importance of new email" : "Автоматично визначати важливість нових листів",
     "Could not update preference" : "Не вдалося оновити уподобання",
     "Select an alias" : "Виберіть синонім",
+    "Select certificates" : "Виберіть сертифікати",
     "Update Certificate" : "Оновити сертифікат",
     "No certificate" : "Немає сертифіката",
     "Certificate updated" : "Сертифікат оновлено",
@@ -142,6 +147,7 @@ OC.L10N.register(
     "From" : "Від",
     "Select account" : "Оберіть обліковий запис",
     "To" : "Кому",
+    "Select recipient" : "Виберіть отримувача",
     "Contact or email address …" : "Контакт або ел.адреса...",
     "Toggle recipients list mode" : "Перемкнути режим показу отримувачів",
     "Cc" : "Копія",
@@ -204,7 +210,7 @@ OC.L10N.register(
     "Encrypted message" : "Лист із шифруванням",
     "This message is unread" : "Це повідомлення не прочитано",
     "Unfavorite" : "Прибрати зірочку",
-    "Favorite" : "До улюблених",
+    "Favorite" : "Із зірочкою",
     "Unread" : "Непрочитане",
     "Read" : "Читати",
     "Unimportant" : "Неважливе",
@@ -400,6 +406,9 @@ OC.L10N.register(
     "Save autoresponder" : "Зберегти налаштування автовідповідача",
     "Could not open outbox" : "Не вдалося відкрити вихідну скриньку",
     "Pending or not sent messages will show up here" : "Тут відображатимуться незавершені або не надіслані повідомлення",
+    "Copy to \"Sent\" Mailbox" : "Копіювати до \"Надіслані\"",
+    "Copy to Sent Mailbox" : "Копіювати до \"Надіслані\"",
+    "Could not copy to \"Sent\" mailbox" : "Не вдалося скопіюати до \"Надіслані\"",
     "Message could not be sent" : "Повідомлення неможливо надіслати",
     "Message deleted" : "Повідомлення вилучено",
     "Contacts with this address" : "Контакти з такою адресою",
@@ -416,6 +425,7 @@ OC.L10N.register(
     "Search subject" : "Шукати в темі",
     "Body" : "Тіло",
     "Search body" : "Шукати в тілі повідомлень",
+    "Date" : "Дата",
     "Pick a start date" : "Виберіть дату початку",
     "Pick an end date" : "Виберіть дату завершення",
     "Select senders" : "Виберіть відправників",
@@ -427,7 +437,9 @@ OC.L10N.register(
     "Marked as" : "Позначено як",
     "Has attachments" : "Має вкладення",
     "Clear" : "Очистити",
-    "Date" : "Дата",
+    "Has attachment" : "Має вкладення",
+    "Last 7 days" : "За останні 7 днів",
+    "From me" : "Від мене",
     "Enable mail body search" : "Увімкнути пошук в тілі повідомлень",
     "Disabled" : "Вимкнено",
     "Enabled" : "Увімкнено",
