@@ -75,7 +75,7 @@ class IspDb {
 		libxml_use_internal_errors(true);
 		$data = simplexml_load_string($xml);
 
-		if ($data === false || !isset($data->emailProvider)) {
+		if ($data === false || !property_exists($data, 'emailProvider')) {
 			$errors = libxml_get_errors();
 			foreach ($errors as $error) {
 				$this->logger->debug("ISP DB returned an erroneous XML: " . $error->message);
